@@ -1,7 +1,7 @@
 import pkg_resources
 import sys
 
-from elasticgit.manager import EG, F, Q
+from elasticgit.workspace import EG, F, Q
 
 __all__ = ['EG', 'F', 'Q']
 __version__ = pkg_resources.require('elastic-git')[0].version
